@@ -48,7 +48,8 @@
 #include <unistd.h>
 #include <string.h>
 #include <ctype.h>
-
+#include <stdlib.h>
+#include <glib/gi18n.h>
 #include <gio/gio.h>
 
 #include <libanjuta/resources.h>
@@ -95,7 +96,7 @@ struct _BreakpointsDBase
 
 	GtkListStore *model;
 	
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	gchar *cond_history, *loc_history;
 
 	/* Widgets */	
@@ -1423,7 +1424,7 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase, AnjutaSession *se
 static void
 breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 {
-	GladeXML *gxml;
+	GtkBuilder *bxml = gtk_builder_new ();
 	GtkWidget *dialog;
 	GtkWidget *location_label, *location_entry;
 	GtkWidget *condition_entry, *condition_label;
@@ -1432,18 +1433,22 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 	gchar *location = NULL;
 	gchar *uri = NULL;
 	gboolean new_break = FALSE;
+	GError* error = NULL;
 
-	gxml = glade_xml_new (GLADE_FILE,
-						  "breakpoint_properties_dialog", NULL);
-	dialog = glade_xml_get_widget (gxml, "breakpoint_properties_dialog");
+	if (!gtk_builder_add_from_file (bxml, GLADE_FILE, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}
+	dialog = GTK_WIDGET (gtk_builder_get_object (bxml, "breakpoint_properties_dialog"));
 	gtk_window_set_transient_for (GTK_WINDOW (dialog),
 								  GTK_WINDOW (ANJUTA_PLUGIN (bd->plugin)->shell));
-	location_label = glade_xml_get_widget (gxml, "breakpoint_location_label");
-	location_entry = glade_xml_get_widget (gxml, "breakpoint_location_entry");
-	condition_entry = glade_xml_get_widget (gxml, "breakpoint_condition_entry");
-	condition_label = glade_xml_get_widget (gxml, "breakpoint_condition_label");
-	pass_entry = glade_xml_get_widget (gxml, "breakpoint_pass_entry");
-	pass_label = glade_xml_get_widget (gxml, "breakpoint_pass_label");
+	location_label = GTK_WIDGET (gtk_builder_get_object (bxml, "breakpoint_location_label"));
+	location_entry = GTK_WIDGET (gtk_builder_get_object (bxml, "breakpoint_location_entry"));
+	condition_entry = GTK_WIDGET (gtk_builder_get_object (bxml, "breakpoint_condition_entry"));
+	condition_label = GTK_WIDGET (gtk_builder_get_object (bxml, "breakpoint_condition_label"));
+	pass_entry = GTK_WIDGET (gtk_builder_get_object (bxml, "breakpoint_pass_entry"));
+	pass_label = GTK_WIDGET (gtk_builder_get_object (bxml, "breakpoint_pass_label"));
 
 	if (bd->debugger != NULL)
 	{
@@ -1587,7 +1592,7 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 	g_free (uri);
 	g_free (location);
 	gtk_widget_destroy (dialog);
-	g_object_unref (gxml);
+	g_object_unref (bxml);
 }
 
 /* Breakpoint actions list
