@@ -42,11 +42,9 @@
 #include <libanjuta/interfaces/ianjuta-file-savable.h>
 #include <libanjuta/anjuta-utils.h>
 
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-
-#include <glade/glade-xml.h>
-
+#include <gio/gio.h>
+#include <glib/gi18n.h>
+#include <stdlib.h>
 #include <errno.h>
 #include <sys/stat.h>
 #include <ctype.h>
@@ -125,6 +123,8 @@ struct _DmaStart
 
 	gboolean stop_at_beginning;
 	GList *source_dirs;
+
+	gchar *remote_debugger;
 	
 	gchar *build_target;
 	IAnjutaBuilderHandle build_handle;
@@ -136,11 +136,20 @@ struct _DmaStart
 #define ADD_SOURCE_DIALOG "source_paths_dialog"
 #define SOURCE_ENTRY "src_entry"
 #define SOURCE_LIST "src_clist"
-#define ADD_BUTTON "add_button"
+#define ADD_BUTTON "source_paths_add_button"
 #define REMOVE_BUTTON "remove_button"
 #define UP_BUTTON "up_button"
 #define DOWN_BUTTON "down_button"
 
+#define REMOTE_DEBUG_DIALOG "remote_dialog"
+#define TCPIP_ADDRESS_ENTRY "tcpip_address_entry"
+#define TCPIP_PORT_ENTRY "tcpip_port_entry"
+#define TCPIP_RADIO "tcpip_radio"
+#define TCPIP_CONTAINER "tcpip_container"
+#define SERIAL_PORT_ENTRY "serial_port_entry"
+#define SERIAL_RADIO "serial_radio"
+#define SERIAL_CONTAINER "serial_container"
+
 /* Constants
  *---------------------------------------------------------------------------*/
 
@@ -170,10 +179,13 @@ get_source_directories (AnjutaPlugin *plugin)
 	GList *slibs_dirs = NULL;
 	GList *libs_dirs = NULL;
 	GValue value = {0,};
+	GFile *file;
 
 	return NULL;
 	cwd = g_get_current_dir();
-	search_dirs = g_list_prepend (search_dirs, gnome_vfs_get_uri_from_local_path(cwd));
+	file = g_file_new_for_path (cwd);
+	search_dirs = g_list_prepend (search_dirs, g_file_get_uri (file));
+	g_object_unref (file);
 	g_free (cwd);
 
 	/* Check if a project is already open */
@@ -244,6 +256,7 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase, AnjutaSession *se
 
 	anjuta_session_set_string_list (session, "Debugger", "Source directories", self->source_dirs);
 	anjuta_session_set_int (session, "Debugger", "Stop at beginning", self->stop_at_beginning + 1);
+	anjuta_session_set_string (session, "Debugger", "Remote target", self->remote_debugger);
 }
 
 static void on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase, AnjutaSession *session, DmaStart *self)
@@ -266,6 +279,9 @@ static void on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase, Anjut
 		self->stop_at_beginning = TRUE;	/* Default value */
 	else
 		self->stop_at_beginning = stop_at_beginning - 1;
+	
+	g_free (self->remote_debugger);
+	self->remote_debugger = anjuta_session_get_string (session, "Debugger", "Remote target");
 }
 
 /* Attach to process private functions
@@ -703,7 +719,6 @@ on_toggle_process_tree (GtkToggleButton *togglebutton, AttachProcess * ap)
 static pid_t
 attach_process_show (AttachProcess * ap, GtkWindow *parent)
 {
-	GladeXML *gxml;
 	GtkTreeView *view;
 	GtkTreeStore *store;
 	GtkCellRenderer *renderer;
@@ -718,16 +733,23 @@ attach_process_show (AttachProcess * ap, GtkWindow *parent)
 
 	if (!ap->dialog)
 	{
-		gxml = glade_xml_new (GLADE_FILE, "attach_process_dialog", NULL);
-		ap->dialog = glade_xml_get_widget (gxml, "attach_process_dialog");
-		ap->treeview = glade_xml_get_widget (gxml, "attach_process_tv");
+		GtkBuilder *bxml = gtk_builder_new ();
+		GError* error = NULL;
+
+		if (!gtk_builder_add_from_file (bxml, GLADE_FILE, &error))
+		{
+			g_warning ("Couldn't load builder file: %s", error->message);
+			g_error_free (error);
+		}
+		ap->dialog = GTK_WIDGET (gtk_builder_get_object (bxml, "attach_process_dialog"));
+		ap->treeview = GTK_WIDGET (gtk_builder_get_object (bxml, "attach_process_tv"));
 		checkb_hide_paths = GTK_CHECK_BUTTON (
-								glade_xml_get_widget (gxml, "checkb_hide_paths"));
+								gtk_builder_get_object (bxml, "checkb_hide_paths"));
 		checkb_hide_params = GTK_CHECK_BUTTON (
-								glade_xml_get_widget (gxml, "checkb_hide_params"));
+								gtk_builder_get_object (bxml, "checkb_hide_params"));
 		checkb_process_tree = GTK_CHECK_BUTTON (
-								glade_xml_get_widget (gxml, "checkb_process_tree"));
-		g_object_unref (gxml);
+								gtk_builder_get_object (bxml, "checkb_process_tree"));
+		g_object_unref (bxml);
 	
 		view = GTK_TREE_VIEW (ap->treeview);
 		store = gtk_tree_store_new (COLUMNS_NB,
@@ -822,7 +844,7 @@ show_parameters_dialog (DmaStart *this)
 }
 
 static gboolean
-start_target (DmaStart *this)
+start_remote_target (DmaStart *this, const gchar *target)
 {
 	gchar *dir_uri;
 	gchar *dir;
@@ -839,7 +861,7 @@ start_target (DmaStart *this)
 	
 	if (dir_uri != NULL)
 	{
-		dir = gnome_vfs_get_local_path_from_uri (dir_uri);
+		dir = anjuta_util_get_local_path_from_uri (dir_uri);
 		g_free (dir_uri);
 	}
 	else
@@ -853,34 +875,72 @@ start_target (DmaStart *this)
 	dma_queue_set_environment (this->debugger, env);
 	g_strfreev (env);
 	
-	dma_queue_start (this->debugger, args, run_in_terminal, FALSE);
+	if (target == NULL)
+	{
+		dma_queue_start (this->debugger, args, run_in_terminal, FALSE);
+	}
+	else
+	{
+		dma_queue_connect (this->debugger, target, args, run_in_terminal, FALSE);
+	}
 	g_free (args);
 	
 	return TRUE;
 
 }
 
+static gboolean
+start_target (DmaStart *this)
+{
+	return start_remote_target (this, NULL);
+}
+
 static gboolean
 load_target (DmaStart *this, const gchar *target)
 {
 	gchar *mime_type;
 	gchar *filename;
+	GFile *file;
+	GFileInfo *file_info;
+	GError *error = NULL;
 	
-	mime_type = gnome_vfs_get_mime_type ((const gchar *)target);
+	DEBUG_PRINT ("Using target %s", target);
+	file = g_file_new_for_uri (target);
+	file_info = g_file_query_info (file, 
+			G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+			G_FILE_QUERY_INFO_NONE,
+			NULL, &error);
+	if (file_info == NULL)
+	{
+		DEBUG_PRINT ("Error getting file info: %s", error->message);
+		g_error_free (error);
+		anjuta_util_dialog_error(GTK_WINDOW (this->plugin->shell),
+				_("Unable to open %s. Debugger cannot start."), target);
+		g_object_unref (file);
+		return FALSE;
+	}
+
+	mime_type = g_file_info_get_attribute_as_string (file_info, 
+			G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
 	if (mime_type == NULL)
 	{
 		anjuta_util_dialog_error(GTK_WINDOW (this->plugin->shell),
-				_("Unable to open %s. Debugger cannot start."), target);
+				_("Unable to detect mime-type of %s. Debugger cannot start."), target);
+		g_object_unref (file_info);
+		g_object_unref (file);
 		return FALSE;
 	}
-	filename = gnome_vfs_get_local_path_from_uri (target);
+
+	filename = g_file_get_path (file);
 	
 	dma_queue_load (this->debugger, filename, mime_type, this->source_dirs);
 
 	g_free (filename);
 	g_free (mime_type);
+	g_object_unref (file_info);
+	g_object_unref (file);
 
-	return start_target (this);
+	return TRUE;
 }
 
 static void
@@ -892,6 +952,7 @@ on_build_finished (GObject *builder, IAnjutaBuilderHandle handle, GError *err, g
 	{
 		/* Up to date, start debugger */
 		load_target (this, this->build_target);
+		start_target (this);
 	}
 	
 	g_free (this->build_target);
@@ -907,6 +968,7 @@ on_is_built_finished (GObject *builder, IAnjutaBuilderHandle handle, GError *err
 	{
 		/* Up to date, start debugger */
 		load_target (this, this->build_target);
+		start_target (this);
 	}
 	else
 	{
@@ -951,25 +1013,132 @@ check_target (DmaStart *this, const gchar *target)
 	else
 	{
 		/* Unable to build target, just launch debugger */
-		return load_target (this, target);
+		return load_target (this, target) && start_target (this);
 	}	
 }
 
 static gboolean
 dma_start_load_and_start_uri (DmaStart *this, const gchar *target)
 {
-	GnomeVFSURI *vfs_uri;
+	gchar *local_path = NULL;
 
 	if (!dma_quit_debugger (this)) return FALSE;
 	
-	vfs_uri = gnome_vfs_uri_new (target);
-	g_return_val_if_fail (vfs_uri != NULL, TRUE);
-	if (!gnome_vfs_uri_is_local (vfs_uri)) return FALSE;
-	gnome_vfs_uri_unref (vfs_uri);
+	local_path = anjuta_util_get_local_path_from_uri (target);
+	if (!local_path)
+	{
+		return FALSE;
+	}
+	g_free (local_path);
 	
 	return check_target (this, target);
 }
 
+/* Remote target dialog
+ *---------------------------------------------------------------------------*/
+
+static void on_radio_toggled(GtkWidget* toggle_button, GtkWidget* container)
+{
+	gtk_widget_set_sensitive(container, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle_button)));
+}
+
+static gboolean
+show_remote_dialog (DmaStart *this)
+{
+	GtkBuilder *bxml = gtk_builder_new ();
+	GtkWindow *parent;
+	GtkWidget *dialog;
+	GtkEntry *tcpip_address_entry;
+	GtkEntry *tcpip_port_entry;
+	GtkEntry *serial_port_entry;
+	GtkToggleButton *serial_radio;
+	GtkToggleButton *tcpip_radio;
+	GtkWidget *container;
+	GError* error = NULL;
+	gint res;
+
+	parent = GTK_WINDOW (this->plugin->shell);
+
+	if (!gtk_builder_add_from_file (bxml, GLADE_FILE, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		anjuta_util_dialog_error(parent, _("Missing file %s"), GLADE_FILE);
+		g_error_free (error);
+		return FALSE;
+	}
+
+	/* Fetch out the widget we care about for now */
+	dialog = GTK_WIDGET (gtk_builder_get_object (bxml, REMOTE_DEBUG_DIALOG));
+	tcpip_address_entry = GTK_ENTRY (gtk_builder_get_object (bxml, TCPIP_ADDRESS_ENTRY));
+	tcpip_port_entry = GTK_ENTRY (gtk_builder_get_object (bxml, TCPIP_PORT_ENTRY));
+	serial_port_entry = GTK_ENTRY (gtk_builder_get_object (bxml, SERIAL_PORT_ENTRY));
+	tcpip_radio = GTK_TOGGLE_BUTTON (gtk_builder_get_object (bxml, TCPIP_RADIO));
+	serial_radio = GTK_TOGGLE_BUTTON (gtk_builder_get_object (bxml, SERIAL_RADIO));
+	
+	/* Connect signals */	
+	container = GTK_WIDGET (gtk_builder_get_object (bxml, TCPIP_CONTAINER));
+	g_signal_connect (G_OBJECT (tcpip_radio), "toggled", G_CALLBACK (on_radio_toggled), container);
+	container = GTK_WIDGET (gtk_builder_get_object (bxml, SERIAL_CONTAINER));
+	g_signal_connect (G_OBJECT (serial_radio), "toggled", G_CALLBACK (on_radio_toggled), container);	
+	g_object_unref (bxml);
+
+	/* Populate the remote target */
+	if (this->remote_debugger)
+	{
+		if (strncmp(this->remote_debugger, "tcp:", 4) == 0)
+		{
+			gchar *port = strrchr (this->remote_debugger, ':');
+			
+			if (port != NULL)
+			{
+				gtk_entry_set_text (GTK_ENTRY (tcpip_port_entry), port + 1);
+				*port = '\0';
+			}
+			gtk_entry_set_text (GTK_ENTRY (tcpip_address_entry), this->remote_debugger + 4);
+			if (port != NULL) *port = ':';
+			gtk_toggle_button_set_active (tcpip_radio, TRUE);
+			gtk_toggle_button_set_active (serial_radio, FALSE);
+		}
+		else if (strncmp(this->remote_debugger,"serial:", 7) == 0)
+		{
+			gtk_entry_set_text (GTK_ENTRY (serial_port_entry), this->remote_debugger + 7);
+			gtk_toggle_button_set_active (serial_radio, TRUE);
+			gtk_toggle_button_set_active (tcpip_radio, FALSE);
+		}
+	}
+
+	res = gtk_dialog_run (GTK_DIALOG (dialog));
+	
+	if (res == GTK_RESPONSE_APPLY || res == GTK_RESPONSE_ACCEPT)
+	{
+		/* Save these settings */
+		g_free (this->remote_debugger);
+		if (gtk_toggle_button_get_active (serial_radio))
+		{
+			this->remote_debugger = g_strconcat ("serial:",
+				gtk_entry_get_text (serial_port_entry),
+				NULL);
+		}
+		else
+		{
+			this->remote_debugger = g_strconcat ("tcp:",
+				gtk_entry_get_text (tcpip_address_entry),
+				":",
+				gtk_entry_get_text (tcpip_port_entry),
+				NULL);
+		}
+	}
+	gtk_widget_destroy (dialog);
+
+	if (res == GTK_RESPONSE_ACCEPT)
+	{
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+
 /* Add source dialog
  *---------------------------------------------------------------------------*/
 
@@ -980,7 +1149,7 @@ on_add_uri_in_model (gpointer data, gpointer user_data)
 	GtkTreeIter iter;
 	gchar *local;
 	
-	local = gnome_vfs_get_local_path_from_uri ((const char *)data);
+	local = anjuta_util_get_local_path_from_uri ((const char *)data);
 	gtk_list_store_append (model, &iter);
 	gtk_list_store_set (model, &iter, 0, local, -1);
 	g_free (local);
@@ -992,10 +1161,13 @@ on_add_source_in_list (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter
 	GList** list = (GList **)user_data;
 	gchar* dir;
 	gchar* uri;
+	GFile *file;
 
 	gtk_tree_model_get (model, iter, 0, &dir, -1);
-	uri =  gnome_vfs_get_uri_from_local_path (dir);
+	file = g_file_new_for_path (dir);
+	uri =  g_file_get_uri (file);
 	*list = g_list_prepend (*list, uri);
+	g_object_unref (file);
 	g_free (dir);
 	
 	return FALSE;
@@ -1072,36 +1244,39 @@ static void
 add_source_show (DmaStart *this)
 {
 	AddSourceDialog dlg;
-	GladeXML *gxml;
+	GtkBuilder *bxml = gtk_builder_new ();
 	GtkWidget *widget;
 	GtkWindow *parent;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GObject *button;
-	
+	GError* error = NULL;
+
 	parent = GTK_WINDOW (this->plugin->shell);
-	gxml = glade_xml_new (GLADE_FILE, ADD_SOURCE_DIALOG, NULL);
-	if (gxml == NULL)
+
+	if (!gtk_builder_add_from_file (bxml, GLADE_FILE, &error))
 	{
+		g_warning ("Couldn't load builder file: %s", error->message);
 		anjuta_util_dialog_error(parent, _("Missing file %s"), GLADE_FILE);
+		g_error_free (error);
 		return;
 	}
 		
-	widget = glade_xml_get_widget (gxml, ADD_SOURCE_DIALOG);
-	dlg.tree = GTK_TREE_VIEW (glade_xml_get_widget (gxml, SOURCE_LIST));
-	dlg.entry = GTK_FILE_CHOOSER (glade_xml_get_widget (gxml, SOURCE_ENTRY));
+	widget = GTK_WIDGET (gtk_builder_get_object (bxml, ADD_SOURCE_DIALOG));
+	dlg.tree = GTK_TREE_VIEW (gtk_builder_get_object (bxml, SOURCE_LIST));
+	dlg.entry = GTK_FILE_CHOOSER (gtk_builder_get_object (bxml, SOURCE_ENTRY));
 	
 	/* Connect signals */	
-	button = G_OBJECT (glade_xml_get_widget (gxml, ADD_BUTTON));
+	button = gtk_builder_get_object (bxml, ADD_BUTTON);
 	g_signal_connect (button, "clicked", G_CALLBACK (on_source_add_button), &dlg);
-	button = G_OBJECT (glade_xml_get_widget (gxml, REMOVE_BUTTON));
+	button = gtk_builder_get_object (bxml, REMOVE_BUTTON);
 	g_signal_connect (button, "clicked", G_CALLBACK (on_source_remove_button), &dlg);
-	button = G_OBJECT (glade_xml_get_widget (gxml, UP_BUTTON));
+	button = gtk_builder_get_object (bxml, UP_BUTTON);
 	g_signal_connect (button, "clicked", G_CALLBACK (on_source_up_button), &dlg);
-	button = G_OBJECT (glade_xml_get_widget (gxml, DOWN_BUTTON));
+	button = gtk_builder_get_object (bxml, DOWN_BUTTON);
 	g_signal_connect (button, "clicked", G_CALLBACK (on_source_down_button), &dlg);
 	
-	g_object_unref (gxml);
+	g_object_unref (bxml);
 
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Path"), renderer, "text", 0, NULL);
@@ -1109,7 +1284,7 @@ add_source_show (DmaStart *this)
 	gtk_tree_view_append_column (dlg.tree, column);
 	gtk_tree_view_set_expander_column(dlg.tree, column);
 	
-	dlg.model = gtk_list_store_new (1, GTK_TYPE_STRING);
+	dlg.model = gtk_list_store_new (1, G_TYPE_STRING);
 	gtk_tree_view_set_model (dlg.tree, GTK_TREE_MODEL (dlg.model));
 	
 	gtk_window_set_transient_for (GTK_WINDOW (widget), parent);
@@ -1197,29 +1372,70 @@ dma_attach_to_process (DmaStart* this)
 }
 
 gboolean
-dma_run_target (DmaStart *this)
+dma_run_target (DmaStart *this, const gchar *target)
 {
-	gchar *target;
+	gchar *target_uri = NULL;
 
-	anjuta_shell_get (ANJUTA_PLUGIN (this->plugin)->shell,
-	 				  RUN_PROGRAM_URI, G_TYPE_STRING, &target, NULL);	
+	if (target == NULL)
+	{
+		anjuta_shell_get (ANJUTA_PLUGIN (this->plugin)->shell,
+	 				  RUN_PROGRAM_URI, G_TYPE_STRING, &target_uri, NULL);	
+		target = target_uri;
+	}
 	
 	if (target == NULL)
 	{
 		/* Launch parameter dialog to get a target name */
 		show_parameters_dialog (this);
 		anjuta_shell_get (ANJUTA_PLUGIN (this->plugin)->shell,
-	 				  RUN_PROGRAM_URI, G_TYPE_STRING, &target, NULL);
+	 				  RUN_PROGRAM_URI, G_TYPE_STRING, &target_uri, NULL);
 		/* No target set by user */
-		if (target == NULL) return FALSE;
+		if (target_uri == NULL) return FALSE;
+		target = target_uri;
 	}
 	
 	if (!dma_start_load_and_start_uri (this, target)) return FALSE;
-	g_free (target);
+	g_free (target_uri);
 	
 	return TRUE;
 }
 
+gboolean
+dma_run_remote_target (DmaStart *this, const gchar *remote, const gchar *target)
+{
+	gchar *target_uri;
+
+	if (target == NULL)
+	{
+		anjuta_shell_get (ANJUTA_PLUGIN (this->plugin)->shell,
+		 				  RUN_PROGRAM_URI, G_TYPE_STRING, &target_uri, NULL);	
+		target = target_uri;
+	}
+	
+	if (target == NULL)
+	{
+		/* Launch parameter dialog to get a target name */
+		show_parameters_dialog (this);
+		anjuta_shell_get (ANJUTA_PLUGIN (this->plugin)->shell,
+	 				  RUN_PROGRAM_URI, G_TYPE_STRING, &target_uri, NULL);
+		/* No target set by user */
+		if (target_uri == NULL) return FALSE;
+		target = target_uri;
+	}
+	
+	if (remote == NULL)
+	{
+		if (!show_remote_dialog (this)) return FALSE;
+		remote = this->remote_debugger;		
+		if (remote == NULL) return FALSE;
+	}
+
+	if (!load_target (this, target)) return FALSE;
+	g_free (target_uri);
+	
+	return start_remote_target (this, remote);
+}
+
 /* Constructor & Destructor
  *---------------------------------------------------------------------------*/
 
