@@ -46,8 +46,10 @@
 #include "git-pull-dialog.h"
 #include "git-cat-file-menu.h"
 #include "git-push-dialog.h"
+#include "git-apply-mailbox-dialog.h"
+#include "git-cherry-pick-dialog.h"
 
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-git.ui"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-git.xml"
 
 static gpointer parent_class;
 
@@ -116,6 +118,14 @@ static GtkActionEntry actions_git[] =
 		NULL,                                     /* short-cut */
 		NULL,                      /* Tooltip */
 		G_CALLBACK (on_menu_git_rebase_abort)    /* action callback */
+	},
+		{
+		"ActionGitPush",                       /* Action name */
+		GTK_STOCK_GO_FORWARD,                            /* Stock icon, if any */
+		N_("_Push..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_push)    /* action callback */
 	},
 	{
 		"ActionGitPull",                       /* Action name */
@@ -126,12 +136,36 @@ static GtkActionEntry actions_git[] =
 		G_CALLBACK (on_menu_git_pull)    /* action callback */
 	},
 	{
-		"ActionGitUnstageFiles",                       /* Action name */
-		GTK_STOCK_CANCEL,                            /* Stock icon, if any */
-		N_("_Unstage files..."),                     /* Display label */
+		"ActionGitDiffUncommitted",                       /* Action name */
+		GTK_STOCK_ZOOM_100,                            /* Stock icon, if any */
+		N_("_Diff uncommitted changes"),                     /* Display label */
 		NULL,                                     /* short-cut */
 		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_unstage)    /* action callback */
+		G_CALLBACK (on_menu_git_diff)    /* action callback */
+	},
+	{
+		"ActionGitAdd",                       /* Action name */
+		GTK_STOCK_ADD,                            /* Stock icon, if any */
+		N_("_Add..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_add)    /* action callback */
+	},
+	{
+		"ActionGitRemove",                       /* Action name */
+		GTK_STOCK_REMOVE,                            /* Stock icon, if any */
+		N_("_Remove..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_remove)    /* action callback */
+	},
+	{
+		"ActionGitIgnore",                       /* Action name */
+		GTK_STOCK_DIALOG_ERROR,                            /* Stock icon, if any */
+		N_("_Ignore..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_ignore)    /* action callback */
 	},
 	{
 		"ActionGitCheckoutFiles",                       /* Action name */
@@ -141,6 +175,14 @@ static GtkActionEntry actions_git[] =
 		NULL,                      /* Tooltip */
 		G_CALLBACK (on_menu_git_checkout_files)    /* action callback */
 	},
+	{
+		"ActionGitUnstageFiles",                       /* Action name */
+		GTK_STOCK_CANCEL,                            /* Stock icon, if any */
+		N_("_Unstage files..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_unstage)    /* action callback */
+	},
 	{
 		"ActionGitResolve",                       /* Action name */
 		GTK_STOCK_PREFERENCES,                            /* Stock icon, if any */
@@ -149,6 +191,14 @@ static GtkActionEntry actions_git[] =
 		NULL,                      /* Tooltip */
 		G_CALLBACK (on_menu_git_resolve)    /* action callback */
 	},
+	{
+		"ActionMenuGitPatches",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("Patches"),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		NULL    /* action callback */
+	},
 	{
 		"ActionGitCreatePatchSeries",                       /* Action name */
 		GTK_STOCK_DND_MULTIPLE,                            /* Stock icon, if any */
@@ -157,6 +207,126 @@ static GtkActionEntry actions_git[] =
 		NULL,                      /* Tooltip */
 		G_CALLBACK (on_menu_git_create_patch_series)    /* action callback */
 	},
+	{
+		"ActionMenuGitApplyMailboxFiles",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("Apply mailbox files"),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		NULL    /* action callback */
+	},
+	{
+		"ActionGitApplyMailboxApply",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("_Apply..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_apply_mailbox_apply)    /* action callback */
+	},
+	{
+		"ActionGitApplyMailboxContinue",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("_Continue with resolved conflicts"),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_apply_mailbox_resolved)    /* action callback */
+	},
+	{
+		"ActionGitApplyMailboxSkip",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("_Skip current patch"),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_apply_mailbox_skip)    /* action callback */
+	},
+	{
+		"ActionGitApplyMailboxAbort",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("_Abort"),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_apply_mailbox_abort)    /* action callback */
+	},
+	{
+		"ActionMenuGitBranches",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("_Branches"),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		NULL    /* action callback */
+	},
+	{
+		"ActionGitCreateBranch",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("_Create branch..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_create_branch)    /* action callback */
+	},
+	{
+		"ActionGitDeleteBranch",                       /* Action name */
+		GTK_STOCK_DELETE,                            /* Stock icon, if any */
+		N_("_Delete branch..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_delete_branch)    /* action callback */
+	},
+	{
+		"ActionGitSwitch",                       /* Action name */
+		GTK_STOCK_JUMP_TO,                            /* Stock icon, if any */
+		N_("_Switch to another branch..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_switch)    /* action callback */
+	},
+	{
+		"ActionGitMerge",                       /* Action name */
+		GTK_STOCK_CONVERT,                            /* Stock icon, if any */
+		N_("_Merge..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_merge)    /* action callback */
+	},
+	{
+		"ActionGitCherryPick",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("_Cherry pick..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_cherry_pick)    /* action callback */
+	},
+	{
+		"ActionMenuGitRemoteBranches",                       /* Action name */
+		GTK_STOCK_NETWORK,                            /* Stock icon, if any */
+		N_("_Remote branches"),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		NULL    /* action callback */
+	},
+	{
+		"ActionGitRemoteAdd",                       /* Action name */
+		GTK_STOCK_ADD,                            /* Stock icon, if any */
+		N_("_Add..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_add_remote)    /* action callback */
+	},
+	{
+		"ActionGitRemoteDelete",                       /* Action name */
+		GTK_STOCK_DELETE,                            /* Stock icon, if any */
+		N_("_Delete..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_delete_remote)    /* action callback */
+	},
+	{
+		"ActionGitCreateTag",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("_Create tag..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_menu_git_create_tag)    /* action callback */
+	},
 	{
 		"ActionGitReset",                       /* Action name */
 		GTK_STOCK_REFRESH,                            /* Stock icon, if any */
@@ -173,14 +343,6 @@ static GtkActionEntry actions_git[] =
 		NULL,                      /* Tooltip */
 		G_CALLBACK (on_menu_git_revert)    /* action callback */
 	},
-	{
-		"ActionMenuGitBranches",                       /* Action name */
-		NULL,                            /* Stock icon, if any */
-		N_("_Branches"),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		NULL    /* action callback */
-	},
 	{
 		"ActionMenuGitBisect",                       /* Action name */
 		NULL,                            /* Stock icon, if any */
@@ -228,111 +390,6 @@ static GtkActionEntry actions_git[] =
 		NULL,                                     /* short-cut */
 		NULL,                      /* Tooltip */
 		G_CALLBACK (on_menu_git_log)    /* action callback */
-	},
-	{
-		"ActionGitAdd",                       /* Action name */
-		GTK_STOCK_ADD,                            /* Stock icon, if any */
-		N_("_Add..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_add)    /* action callback */
-	},
-	{
-		"ActionGitRemove",                       /* Action name */
-		GTK_STOCK_REMOVE,                            /* Stock icon, if any */
-		N_("_Remove..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_remove)    /* action callback */
-	},
-	{
-		"ActionGitIgnore",                       /* Action name */
-		GTK_STOCK_DIALOG_ERROR,                            /* Stock icon, if any */
-		N_("_Ignore..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_ignore)    /* action callback */
-	},
-	
-	{
-		"ActionGitCreateBranch",                       /* Action name */
-		NULL,                            /* Stock icon, if any */
-		N_("_Create branch..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_create_branch)    /* action callback */
-	},
-	{
-		"ActionGitDeleteBranch",                       /* Action name */
-		GTK_STOCK_DELETE,                            /* Stock icon, if any */
-		N_("_Delete branch..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_delete_branch)    /* action callback */
-	},
-	{
-		"ActionGitSwitch",                       /* Action name */
-		GTK_STOCK_JUMP_TO,                            /* Stock icon, if any */
-		N_("_Switch to another branch..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_switch)    /* action callback */
-	},
-	{
-		"ActionGitMerge",                       /* Action name */
-		GTK_STOCK_CONVERT,                            /* Stock icon, if any */
-		N_("_Merge..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_merge)    /* action callback */
-	},
-	{
-		"ActionMenuGitRemoteBranches",                       /* Action name */
-		GTK_STOCK_NETWORK,                            /* Stock icon, if any */
-		N_("_Remote branches"),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		NULL    /* action callback */
-	},
-	{
-		"ActionGitRemoteAdd",                       /* Action name */
-		GTK_STOCK_ADD,                            /* Stock icon, if any */
-		N_("_Add..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_add_remote)    /* action callback */
-	},
-	{
-		"ActionGitRemoteDelete",                       /* Action name */
-		GTK_STOCK_DELETE,                            /* Stock icon, if any */
-		N_("_Delete..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_delete_remote)    /* action callback */
-	},
-	{
-		"ActionGitCreateTag",                       /* Action name */
-		NULL,                            /* Stock icon, if any */
-		N_("_Create tag..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_create_tag)    /* action callback */
-	},
-	{
-		"ActionGitDiffUncommitted",                       /* Action name */
-		GTK_STOCK_ZOOM_100,                            /* Stock icon, if any */
-		N_("_Diff uncommitted changes"),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_diff)    /* action callback */
-	},
-	{
-		"ActionGitPush",                       /* Action name */
-		GTK_STOCK_GO_FORWARD,                            /* Stock icon, if any */
-		N_("_Push..."),                     /* Display label */
-		NULL,                                     /* short-cut */
-		NULL,                      /* Tooltip */
-		G_CALLBACK (on_menu_git_push)    /* action callback */
 	}
 };
 
@@ -386,6 +443,14 @@ static GtkActionEntry actions_log[] =
 		NULL,                      /* Tooltip */
 		G_CALLBACK (on_log_menu_git_revert)    /* action callback */
 	},
+	{
+		"ActionGitLogCherryPick",                       /* Action name */
+		NULL,                            /* Stock icon, if any */
+		N_("_Cherry pick..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		NULL,                      /* Tooltip */
+		G_CALLBACK (on_log_menu_git_cherry_pick)    /* action callback */
+	},
 	{
 		"ActionMenuGitLogBisect",                       /* Action name */
 		NULL,                            /* Stock icon, if any */
@@ -482,6 +547,8 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	g_free (project_root_uri);
 	
 	git_plugin->bisect_file_monitor = bisect_menus_init (git_plugin);
+	git_plugin->log_refresh_monitor = git_log_setup_refresh_monitor (git_plugin);
+	git_log_refresh_branches (git_plugin);
 }
 
 static void
@@ -513,6 +580,7 @@ on_project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 	git_log_window_clear (git_plugin);
 	
 	g_file_monitor_cancel (git_plugin->bisect_file_monitor);
+	g_file_monitor_cancel (git_plugin->log_refresh_monitor);
 	g_object_unref (git_plugin->bisect_file_monitor);
 }
 
