@@ -321,9 +321,17 @@ ianjuta_msgman_add_view (IAnjutaMessageManager *plugin,
 	GtkWidget *msgman = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->msgman;
 	if (ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->widget_shown == FALSE)
 	{
-		anjuta_shell_add_widget (shell, msgman,
+		GtkWidget* label = gtk_label_new (_("Messages"));
+		GtkWidget* image = gtk_image_new_from_stock ("message-manager-plugin-icon",
+		                                            GTK_ICON_SIZE_MENU);
+		GtkWidget* hbox = anjuta_msgman_get_hbox (ANJUTA_MSGMAN(msgman));
+		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+		gtk_widget_show_all (hbox);
+		
+		anjuta_shell_add_widget_custom (shell, msgman,
 							 "AnjutaMessageView", _("Messages"),
-							 "message-manager-plugin-icon",
+							 "message-manager-plugin-icon", hbox,
 							 ANJUTA_SHELL_PLACEMENT_BOTTOM, NULL);
 		ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->widget_shown = TRUE;
 	}
